#
# spec file for package mate-screensaver
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _version 1.16
Name:           mate-screensaver
Version:        1.16.1
Release:        1.1
Summary:        MATE Desktop screensaver
License:        GPL-2.0+ and LGPL-2.0+
Group:          System/GUI/Other
Url:            https://mate-desktop.org/
Source:         http://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE mate-screensaver-1.7.1-vendor_pam_integration.patch nmarques@mate-desktop.org -- PAM integration with SUSE.
Patch0:         %{name}-1.7.1-vendor_pam_integration.patch
BuildRequires:  libmatekbd-devel
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-devel
BuildRequires:  xscreensaver-data
BuildRequires:  xscreensaver-data-extra
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libmate-menu) >= 1.5.0
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(mate-desktop-2.0) >= %{_version}
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
Requires:       mate-session-manager-gschemas >= %{_version}
Recommends:     %{name}-lang
Recommends:     xscreensaver-data
Suggests:       mate-power-manager >= %{_version}
%glib2_gsettings_schema_requires
%if 0%{?suse_version} > 1310
BuildRequires:  pkgconfig(libsystemd)
%else
BuildRequires:  pkgconfig(libsystemd-login)
%endif

%description
mate-screensaver is a screen saver and locker that aims to have simple,
sane, secure defaults and be well integrated with the desktop.

%package devel
Summary:        Development files for mate-screensaver
Group:          Development/Sources
Requires:       %{name} = %{version}

%description devel
mate-screensaver is a screen saver and locker that aims to have simple,
sane, secure defaults and be well integrated with the desktop.

%lang_package

%prep
%setup -q
%patch0 -p1

%build
NOCONFIGURE=1 mate-autogen
%configure  \
  --libexecdir=%{_libexecdir}/%{name} \
  --with-xscreensaverdir=%{_sysconfdir}/xscreensaver \
  --with-pam-prefix=%{_sysconfdir}    \
  --with-gtk=2.0                      \
  --with-systemd                      \
  --without-console-kit               \
  --disable-docbook-docs
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name} %{?no_lang_C}

pushd %{buildroot}%{_datadir}/applications/
for desktop in $(ls | grep \.desktop); do
    %suse_update_desktop_file %{buildroot}%{_datadir}/applications/$desktop
done
popd

%post
%desktop_database_post
%glib2_gsettings_schema_post

%postun
%desktop_database_postun
%glib2_gsettings_schema_postun

%files
%defattr(-,root,root)
%doc README COPYING COPYING.LIB NEWS
%dir %{_sysconfdir}/xdg/menus/
%config %{_sysconfdir}/xdg/menus/mate-screensavers.menu
%config %{_sysconfdir}/xdg/autostart/mate-screensaver.desktop
%config %{_sysconfdir}/pam.d/mate-screensaver
%{_bindir}/%{name}*
%{_libexecdir}/%{name}/
%{_datadir}/applications/*.desktop
%{_datadir}/applications/screensavers/
%{_datadir}/backgrounds/
%{_datadir}/dbus-1/services/*.service
%{_datadir}/desktop-directories/
%{_datadir}/mate-background-properties/
%{_datadir}/%{name}/
%{_datadir}/pixmaps/gnome-logo-white.svg
%{_datadir}/pixmaps/mate-logo-white.svg
%{_datadir}/glib-2.0/schemas/*.xml
%{_mandir}/man?/*.?%{?ext_man}

%files devel
%defattr(-,root,root)
%{_libdir}/pkgconfig/mate-screensaver.pc

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Sun Feb  5 2017 sor.alexei@meowr.ru
- Update to version 1.16.1:
  * Fix build breakage with GTK+ 3.14.
  * Fix "Blank screen" theme with GTK+ 3.22.
  * GTK+2: Fix switching to "Blank screen" theme in the full screen
    preview.
  * Properly restore the password dialogue position after a wrong
    password attempt.
  * Check for a gdm-binary process when switching the user.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Fix locking when screensaver is already active.
  * GTK+3: Fix background and locking in multi-monitor setup.
  * GTK+3: Fix several deprecations.
  * Some more fixes and cleanups.
  * Make distcheck use a currently selected GTK+ version
  * Update translations.
* Sun May 22 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * GTK+-3: Fix assertion 'GTK_IS_WIDGET (widget)' failed.
  * GTK+-3: Add style class lock-dialog.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Update translations.
  * Add Changelog generation.
* Tue Jan 26 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Gtk3: fix several deprecations.
  * Some more fixes and cleanups.
  * Drop MateConf migration script.
* Mon Jan 11 2016 sor.alexei@meowr.ru
- Add missing mate-session-manager-gschemas dependency.
* Mon Nov 23 2015 sor.alexei@meowr.ru
- Use authentication directly via PAM.
- Do not require xscreensaver-data but recommend.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Add support for libsystemd (in addition to libsystemd-login).
  * Some more fixes and cleanups.
* Wed Oct 21 2015 sor.alexei@meowr.ru
- Update to 1.11.1:
  * Fix systemd event handling.
* Fri Oct  9 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Switch to org.gnome.SessionManager.
  * Do not fade to black when locking the screen.
  * manager: fade out explicitly locks more quickly.
  * More improvements.
* Mon Jul 13 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Fix segfault due to wrong object being destroyed.
  * Update translations.
* Fri Jun 12 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Check for running display manager when user switching.
* Mon May  4 2015 sor.alexei@meowr.ru
- Update to 1.10.0:
  * Update translations.
- Spec cleanup.
* Thu Jan 22 2015 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  * Update to api changes for MateRR* in mate-desktop
* Sun Nov 23 2014 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + Minor bug fixes
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + No changelog available
- Fix version requirements
* Fri Oct  3 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + Prevent SegFault in the absence of XRANDR
* Wed Apr  2 2014 p.drouand@gmail.com
- Fix again the patch; uncomment SUSE lines on pam config file
* Sun Mar 30 2014 p.drouand@gmail.com
- Fix mate-screensaver-1.7.1-vendor_pam_integration.patch; it only
  added new lines instead of comment existing ones
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Mon Feb 10 2014 p.drouand@gmail.com
- Update to version 1.7.1 (unstable)
  + pam: Use pam_gnome-keyring.so
  + fix issues when using systemd
  + show date and time in lock dialog
    closes #18 (https://github.com/mate-desktop/mate-screensaver/issues/18)
  + update translations
- Changes from version 1.7.0
  + re-add erroneously removed opening semicolon
  + initial GTK3 support
  + replace mate-open with gvfs-open
- Update mate-screensaver-1.7.1-vendor_pam_integration.patch to upstream
  changes
- Build with systemd support only; remove consolekit workaround
- Remove pkgconfig(libsystemd-daemon) require; only libsystemd-login is
  needed to build
* Sat Aug  3 2013 p.drouand@gmail.com
- Update to version 1.6.1
  + fixes for make dist and make distcheck
  + add xscrnsaver in configure
  + use idle-delay key in org.mate.session schema
    closes #17 https://github.com/mate-desktop/mate-screensaver/issues/17
  + use GDK to detect caps lock state
    closes #16 https://github.com/mate-desktop/mate-screensaver/issues/16
  + update makefiles for automake 1.13
  + add support to switch user with LightDM
* Thu Apr  4 2013 p.drouand@gmail.com
- Update to version 1.6.0
  + no changes since 1.5.2
* Thu Mar 14 2013 p.drouand@gmail.com
- Update to version 1.5.2:
  + Use libnotify instead of libmatenotify
  + AC_CONFIG_HEADERS to please automake 1.13
  + Fix indentation
  + Prevent mate-screensaver to launch a 2nd instance
- Replace libmatenotify BuildRequires with libnotify BuildRequires to
  follow upstream changes
- Remove 0001-prevent-mate-screensaver-to-launch-a-2nd-instance.patch
  Fixed and merged on upstream release
* Sun Feb 24 2013 p.drouand@gmail.com
- Fix permissions for /etc/xdg
* Mon Dec  3 2012 nmo.marques@gmail.com
- Use systemd-login for >= 12.3 and ConsoleKit for previous,
  hopefully fixing hibernate
* Fri Nov 23 2012 nmo.marques@gmail.com
- Update to version 1.5.1
  + Fix FSF address in several files
  + Fix some typos
  + Fix gschema paths
  + Add support for systemd-login
- Remove 2 temporary patches used for testing, merged upstream
* Sat Nov  3 2012 nmo.marques@gmail.com
- Update to version 1.5.0
  + migration to glib-2.0 gsettings
- Remove mate-screensaver-pam_suse.patch, reworked
- Add mate-screensaver-1.5.0-vendor_pam_integration.patch, vendor
  integration with PAM
- Add %%post/%%postun desktop database macros
* Tue Sep 18 2012 nmo.marques@gmail.com
- Fix typo in %%configure instructions and add xscreensavers stuff
* Tue Sep 18 2012 nmo.marques@gmail.com
- Add mate-screensaver-pam_suse.patch: fix pam interaction for
  opensuse
* Fri Sep 14 2012 nmo.marques@gmail.com
- Initial package from version 1.4.0
